@@ -1,3 +1,12 @@
+use std::{
+    cell::{RefCell, RefMut},
+    iter::Fuse,
+    rc::Rc,
+};
+
+use itertools::Itertools;
+use thiserror::Error;
+
 use crate::{
     data_structure::{
         undo::{
@@ -15,13 +24,6 @@ use crate::{
     },
     Array, InputError,
 };
-use itertools::Itertools;
-use std::{
-    cell::{RefCell, RefMut},
-    iter::Fuse,
-    rc::Rc,
-};
-use thiserror::Error;
 
 #[derive(Debug, Clone, Eq, PartialEq, Error)]
 pub(crate) enum ProgramError {
@@ -739,7 +741,7 @@ fn run_code(
                             let sorted_elements = map
                                 .iter()
                                 .map(|(k, v)| (k.clone(), v.clone())) // TODO: Is there a better way?
-                                .sorted_by(|(lhs, _), (rhs, _)| Ord::cmp(lhs, rhs))
+                                .sorted_unstable_by(|(lhs, _), (rhs, _)| Ord::cmp(lhs, rhs))
                                 .collect();
                             PathValueIterator::Object {
                                 sorted_elements: Rc::new(sorted_elements),
